@@ -1,11 +1,11 @@
-local set = require "util.set";
+local set = require "prosody.util.set";
 
 local known_options = {
 	incremental = set.new { "mode", "threshold", "speed", "step_size" };
 	generational = set.new { "mode", "minor_threshold", "major_threshold" };
 };
 
-if _VERSION ~= "5.4" then
+if _VERSION ~= "Lua 5.4" then
 	known_options.generational = nil;
 	known_options.incremental:remove("step_size");
 end
